<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>Nepodařilo se otevřít databázi účtů</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>Přihlášení vypršelo, přihlašte se prosím</translation>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation>Nastavení účtu</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Napište, prosím, adresu serveru</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 není platná adresa serveru</translation>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation>Nelze uložit informace o účtu</translation>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation>Nelze uložit změny: %1</translation>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation>Informace o účtu byly úspěšně změněny</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Server Address</source>
        <translation>Adresa serveru</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation>Nepodařilo se odebrat synchronizaci knihoven tohoto účtu: %1</translation>
    </message>
    <message>
        <source>click to open the website</source>
        <translation>Otevřít v prohlížeči</translation>
    </message>
    <message>
        <source>pro version</source>
        <translation>pro verze</translation>
    </message>
    <message>
        <source>No account</source>
        <translation>Žádný účet</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation>Nastavení účtu</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Přihlásit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Přidat účet</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásit</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>nepřihlášeno</translation>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation>Nepodařilo se odstranit token pro synchronizaci místních repozitářů: %1</translation>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation>Nepodařilo se stáhnout informace o synchronizaci repozitáře ze serveru: %1</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Účet</translation>
    </message>
    <message>
        <source>email</source>
        <translation>email</translation>
    </message>
    <message>
        <source>server</source>
        <translation>server</translation>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation>Aktivita souborů je podporována pouze v %1 Server Professional Edition</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>opakovat</translation>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation>Nepodařilo se získat informace o aktivitách. Prosím% 1</translation>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation>Nahrávání úspěšné</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation>Soubor &quot;%1&quot;
nahrán úspěšně.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation>Soubor &quot;%1&quot;
nahrání selhalo.</translation>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation>Chyba při vytváření složky profilových fotografií</translation>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation>odstranit všechny úspěšné úkoly</translation>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation>Neprobíhá žádné stahování</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Vyčistit</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>Knihovna</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Cesta</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>Zrušit tuto úlohu</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>zrušit tuto úlohu</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>Odebrat tuto úlohu</translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Nemohu zrušit tuto úlohu:

%1</translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>Nemohu odebrat tuto úlohu:

%1</translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>Minimalizovat</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Knihovny</translation>
    </message>
    <message>
        <source>Starred</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation>Aktivity</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>current download rate</source>
        <translation>aktuální rychlost stahování</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>aktuální rychlost uploadu</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation>Vyberte adresář k synchronizaci</translation>
    </message>
    <message>
        <source>no server connected</source>
        <translation>není připojen žádný server</translation>
    </message>
    <message>
        <source>all servers connected</source>
        <translation>všechny servery jsou připojeny</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>některé servery nebyly připojeny</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>minimalizovat</translation>
    </message>
    <message>
        <source>close</source>
        <translation>zavřít</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <source>brand</source>
        <translation>značka</translation>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation>nebo přetáhnout složku k synchronizaci</translation>
    </message>
    <message>
        <source>download rate</source>
        <translation>rychlost stahování</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation>šipka dolů</translation>
    </message>
    <message>
        <source>upload rate</source>
        <translation>rychlost uploadu</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation>šipka nahoru</translation>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation>Chyba při vytváření ccnet konfigurace</translation>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation>Nepodařilo se vytvořit předkonfigurační adresář &quot;%1&quot;</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>chyba při čtení %1</translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>Vytvořit knihovnu</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Vyberte adresář</translation>
    </message>
    <message>
        <source>Creating...</source>
        <translation>Vytvářím...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation>Nepodařilo se vygenerovat šifrovací klíč pro knihovnu</translation>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation>Vyberte adresář k synchronizaci</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>Adresář %1 neexistuje</translation>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>Vložte jméno</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Vložte heslo</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>Hesla se neshodují</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Neznámá chyba</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Nelze přidat stahování:
%1</translation>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation>Nelze vytvořit knihovnu na serveru:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Cesta:</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>šifrováno</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>Heslo znovu:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>stavový text</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>selhalo načtení konfiguračního adresáře ccnet %1</translation>
    </message>
    <message>
        <source>%1 client failed to initialize</source>
        <translation>%1 klient se nepodařilo spustit</translation>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>Vložte heslo</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>Synchronizovat knihovnu %1</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation>Synchronizovat složku &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation>Synchronizovat do složky</translation>
    </message>
    <message>
        <source>or</source>
        <translation>nebo</translation>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation>Synchronizovat existující adresář</translation>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation>Vytvořit nový synchronizační adresář</translation>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation>Synchronizovat tento existující adresář</translation>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation>Prosím zvolte složku</translation>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation>Složka neexistuje</translation>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation>Prosím zvolte složku k dynchronizaci</translation>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation>Vaše organizace znemožnila umístění knihovny mimo adresář %1.</translation>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation>Dochází ke konfliktu se souborem &quot;%1&quot;, prosím zvolte jinou složku.</translation>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation>Dochází ke konfliktu s knihovnou &quot;%1&quot;, prosím zvolte jinou složku.</translation>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation>Složka &quot;%1&quot; již existuje.Jste si jistí že s ní chcete synchronizovat (obsah bude sloučen)?</translation>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation>Klikněte Ne pro synchronizaci s novou složkou</translation>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation>Nepodařilo se najít alternativní název adresáře</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Nelze přidat stahování:
%1</translation>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation>Nepodařilo se stáhnout informace o repozitáři:
%1</translation>
    </message>
    <message>
        <source>Download Library</source>
        <translation>Stáhnout knihovnu</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>vybrat...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>Heslo pro tuto knihovnu:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation>Podrobnosti o změnách</translation>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation>Přidané soubory</translation>
    </message>
    <message>
        <source>Deleted files</source>
        <translation>Smazané soubory</translation>
    </message>
    <message>
        <source>Modified files</source>
        <translation>Změněné soubory</translation>
    </message>
    <message>
        <source>Added folders</source>
        <translation>Přidané složky</translation>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation>Smazané složky</translation>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Otevřít</translation>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation>Otevřít &amp; rodičovská složka</translation>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation>Prohlížeč souborů v Cloudu</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vpřed</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Domů</translation>
    </message>
    <message>
        <source>Upload files</source>
        <translation>Nahrát soubory</translation>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation>Nahrát adresář</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation>Nemáte oprávnění pro nahrání souborů do této knihovny</translation>
    </message>
    <message>
        <source>Create a folder</source>
        <translation>Vytvořit adresář</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder name</source>
        <translation>Jméno adresáře</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Neplatné jméno adresáře!</translation>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation>Jméno &quot;%1&quot; uz existuje.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>opakovat</translation>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation>Chyba při stahování informací o souborech&lt;br/&gt;
Prosím %1</translation>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation>Vložte název souboru, do kterého si přejete uložit...</translation>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation>Nelze odstranit soubor &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation>Vložte cestu ke knihovně, do které si přejete ukládat...</translation>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation>Přejete si přepsat existující soubor &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation>Soubor &quot;%1&quot; nebyl synchronizován</translation>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation>Soubor %1 již existuje.&lt;br/&gt;Chcete ho přepsat?&lt;br/&gt;&lt;small&gt;(Zvolte Ne pokud ho chcete nahrát s jiným názvem).&lt;/small&gt;</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation>Selhalo stažení souboru: %1</translation>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation>Vyberte soubor k nahrání</translation>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation>Vybrat adresář k nahrání</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation>Opravdu chcete smazat tyto položky</translation>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation>Vytváření adresáře selhalo</translation>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation>Uzamčení souboru selhalo</translation>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation>Vybrat soubor pro aktualizaci %1</translation>
    </message>
    <message>
        <source>Rename failed</source>
        <translation>Přejmenování selhalo</translation>
    </message>
    <message>
        <source>Remove failed</source>
        <translation>Odstranění selhalo</translation>
    </message>
    <message>
        <source>Share failed</source>
        <translation>Sdílení selhalo</translation>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation>Nelze vložit soubory z toho samého adresáře</translation>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy failed</source>
        <translation>Kopírování selhalo</translation>
    </message>
    <message>
        <source>Move failed</source>
        <translation>Přesun selhal</translation>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation>Vytvoření knihovny selhalo</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Nahrát</translation>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation>Nahrávám %1</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Stáhnout</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Stahuji %1</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 z %2</translation>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation>Operace zrušena</translation>
    </message>
    <message>
        <source>pending</source>
        <translation>čekající</translation>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Vnitřní chyba serveru</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation>uzamčeno %1</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation>Poslední úprava</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>Druh</translation>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Uložit jako...</translation>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation>&amp;Zamknout</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Přejmenovat</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <source>Share to Group</source>
        <translation>Sdílet se skupinou</translation>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>&amp;Aktualizovat</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovat</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Vyjmou&amp;t</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Vložit</translation>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation>Zrušit stahování</translation>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation>&amp;Synchronizovat tento adresář</translation>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation>Tato funkcionalita je dostupná pouze v PRO verzi
</translation>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation>&amp;Vygenerovat odkaz ke stažení</translation>
    </message>
    <message>
        <source>Share to User</source>
        <translation>Sdílet s uživatelem</translation>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation>Vygenerovat %1 interní odkaz</translation>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation>&amp;Uložit jako do...</translation>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation>Odemknout</translation>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation>S oprávněním ke čtení není možno odstranit soubory </translation>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation>Nelze vyjmout soubory pouze pro čtení</translation>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation>Selhalo vytváření adresářů</translation>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation>Selhalo vytváření dočasných souborů</translation>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation>Selhalo zapsání souboru na disk</translation>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation>Selhalo odstranění starší verze stahovaného souboru</translation>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation>Selhalo přesunutí souboru</translation>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>%1 inicializace</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation>Vyberte adresář %1</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Vyberte adresář</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation>Inicializace není kompletní. Opravdu ukončit?</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>Adresář %1 neexistuje</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation>Vyberte adresář</translation>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation>Prosím vyberte adresář. V něm vytvoříme podadresář %1. Až stáhnete knihovnu, uloží se zde.</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Vybrat...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation>Kontrola výchozí knihovny ...</translation>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation>Vytvářím výchozí knihovnu...</translation>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation>Nepodařilo se vytvoření základní knihovny:

Verze serveru musí být 2.1 nebo vyšší.</translation>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation>Nepodařilo se získat výchozí knihovnu:
%1</translation>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation>Nepodařilo se vytvořit výchozí knihovnu:
%1</translation>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation>Stahuji výchozí knihovnu...</translation>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation>Nelze stáhnout výchozí knihovnu:
%1</translation>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation>Výchozí knihovna byla stažena.
Klikněte na tlačítko &quot;Otevřít&quot; pro zobrazení.</translation>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation>Chyba při stahování výchozí knihovny:
%1</translation>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation>Nelze stáhnout výchozí knihovnu:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation>Přeskočit</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Spustit na pozadí</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Dokončit</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>Stáhnout výchozí knihovnu:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Přidat účet</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Znovu přihlásit</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Přihlašuji se...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Chyba sítě:
%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Varování:&lt;/b&gt; SSL certifikát serveru není důvěryhodný, přesto pokračovat?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Vložte adresu serveru</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 není platná adresa serveru</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Vaše uživatelské jméno</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Název počítače</translation>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>Chyba při ukládání informací o účtu</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation>Dvoufaktorová autentizace</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation>%1 adresa serveru</translation>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Vložte heslo</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation>Vložte dvoufaktorový autentizační token</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>Nesprávný email nebo heslo</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Přihlašujete se příliš často, prosím počkejte chvíli</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Vnitřní chyba serveru</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Chyba při přihlášení: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Chyba při přihlášení</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Například: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>nebo http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>stavový text</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Název počítače:</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation>Email / Uživ. jméno:</translation>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>například Honzův počitač</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation>Jste odhlášen. Prosím</translation>
    </message>
    <message>
        <source>login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Přidat účet</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>Obnovit</translation>
    </message>
</context>
<context>
    <name>MessageListener</name>
    <message>
        <source>failed to load ccnet config dir </source>
        <translation>selhalo načtení konfiguračního adresáře ccnet</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is unsynced. 
Reason: Deleted on server</source>
        <translation>&quot;%1&quot; nelze synchronizovat. 
Příčina: Smazáno na serveru</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>&quot;%1&quot; je synchronizováno</translation>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 conflict</source>
        <translation>Konflikt souboru %1</translation>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation>Nepodařilo se synchronizovat soubor %1
Soubor je uzamčen jiným programem. Tento soubor bude aktualizován, až tento program zavřete.</translation>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation>Nepodařilo se synchronizovat adresář %1
Soubor je uzamčen jiným programem. Tento adresář bude aktualizován, až tento program zavřete.</translation>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other user on the server. Update to this file is not uploaded.</source>
        <translation>Nepodařilo se synchronizovat soubor %1
Soubor je na serveru uzamčen jiným uživatelem. Změny v souboru nebyly nahrány na server.</translation>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation>Nepodařilo se synchronizovat %1
Cesta k souboru obsahuje neplatné znaky. Soubor není na tomto počítači synchronizován.</translation>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation>Indexace souboru %1 se nezdařila. 
Prosím zkontrolujte oprávnění souboru a volné místo.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync. 
Access denied to service</source>
        <translation>Nezdařila se synchronizace &quot;%1&quot;.
Přístup ke službě byl odepřen.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync.
The library owner&apos;s storage space is used up.</source>
        <translation>Nezdařila se synchronizace &quot;%1&quot;.
Majitel knihovny vyčerpal svůj datový limit.</translation>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation>Sdílet %1</translation>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation>Vložte název skupiny</translation>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation>Úspěšně aktualizováno</translation>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation>Operace sdílení selhala: %1</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Úspěšně odstraněno</translation>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation>Nepodařilo se stáhnout informace pro sdílení adresáře</translation>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation>Nepodařilo se stáhnout informace o skupinách a kontaktech</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Prosím zadejte uživatelské jméno</translation>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation>Prosím zadejte název skupiny</translation>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation>Skupina &quot;%1&quot; neexistuje</translation>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation>Se skupinou %1 je již sdíleno</translation>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation>S uživatelem %1 je již sdíleno</translation>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation>Stále probíhá předchozí operace</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Share To:</source>
        <translation>Sdílet s:</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Sdílet</translation>
    </message>
    <message>
        <source>Permission:</source>
        <translation>Oprávnění</translation>
    </message>
    <message>
        <source>Read-Write</source>
        <translation>Číst a zapisovat</translation>
    </message>
    <message>
        <source>Read-Only</source>
        <translation>Pouze číst</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation>synchronizováno</translation>
    </message>
    <message>
        <source>indexing files</source>
        <translation>indexuji soubory</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>Synchronizace zhájena</translation>
    </message>
    <message>
        <source>downloading</source>
        <translation>stahuji</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>Nahrávám</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation>synchronizace spojení</translation>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation>čekám na synchronizaci</translation>
    </message>
    <message>
        <source>server not connected</source>
        <translation>sever není připojen</translation>
    </message>
    <message>
        <source>server authenticating</source>
        <translation>autentizace serveru</translation>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation>automatická synchronizace je vypnuta</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>neznámý/á</translation>
    </message>
    <message>
        <source>Server has been removed</source>
        <translation>Server byl odebrán</translation>
    </message>
    <message>
        <source>You have not logged in to the server</source>
        <translation>Nejste přihlášeni na server</translation>
    </message>
    <message>
        <source>You do not have permission to access this library</source>
        <translation>Nemáte právo přístupu k této knihovně</translation>
    </message>
    <message>
        <source>The storage space of the library owner has been used up</source>
        <translation>Byl dosažen datový limit na severu pro majitele této knihovny </translation>
    </message>
    <message>
        <source>Remote service is not available</source>
        <translation>Vzdálená služba není dostupná</translation>
    </message>
    <message>
        <source>Access denied to service</source>
        <translation>Přístup ke službě zakázán</translation>
    </message>
    <message>
        <source>Internal data corrupted</source>
        <translation>Vnitřní chyba dat</translation>
    </message>
    <message>
        <source>Failed to start upload</source>
        <translation>Problém při startu nahrávání</translation>
    </message>
    <message>
        <source>Error occured in upload</source>
        <translation>Chyba během nahrávání</translation>
    </message>
    <message>
        <source>Failed to start download</source>
        <translation>Chyba při startu stahování</translation>
    </message>
    <message>
        <source>Error occured in download</source>
        <translation>Chyba během stahování</translation>
    </message>
    <message>
        <source>Library is damaged on server</source>
        <translation>Knihovna je poškozena na serveru</translation>
    </message>
    <message>
        <source>Conflict in merge</source>
        <translation>Chyba při sloučení</translation>
    </message>
    <message>
        <source>Server version is too old</source>
        <translation>Verze serveru je zastaralá</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Neznámá chyba</translation>
    </message>
    <message>
        <source>Permission denied on server. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>Kvóta na severu je obsazená</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>Vnitřní chyba serveru</translation>
    </message>
    <message>
        <source>Your %1 client is too old</source>
        <translation>Váš klient %1 je zastaralý</translation>
    </message>
    <message>
        <source>Failed to sync this library</source>
        <translation>Synchronizace této knihovny selhala</translation>
    </message>
    <message>
        <source>Files are locked by other application</source>
        <translation>Soubory jsou uzamčeny jinou aplikací</translation>
    </message>
    <message>
        <source>Library is deleted on server</source>
        <translation>Knihovna je smazána na serveru</translation>
    </message>
    <message>
        <source>Error when accessing the local folder</source>
        <translation>Chyba během přístupu k lokálnímu adresáři</translation>
    </message>
    <message>
        <source>initializing...</source>
        <translation>Inicializuji...</translation>
    </message>
    <message>
        <source>Failed to index local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to check server information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to merge local file changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect password. Please download again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>connecting server...</source>
        <translation>připojuji server...</translation>
    </message>
    <message>
        <source>indexing files...</source>
        <translation>indexuji soubory...</translation>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation>Stahuji seznam souborů...</translation>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation>Stahuji soubory...</translation>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>Vytvářím adresář...</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation>Sloučit změny souborů ...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <source>checking server info...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceling</source>
        <translation>Rušení</translation>
    </message>
    <message>
        <source>Canceled</source>
        <translation>Zrušeno</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>Chyba SSL</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Chyba sítě: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Chyba serveru</translation>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation>Chyba při otevírání databáze certifikátů</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation>Soubor &quot;%1&quot; v &quot;%2&quot; neexistuje</translation>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation>%1 nelze najít aplikaci, která otevře soubor %2</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Vytvořena knihovna &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Smazána knihovna &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation>Přejmenovat %1 na</translation>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation>Není možné stáhnout &quot;%1&quot;</translation>
    </message>
    <message>
        <source>copy failed</source>
        <translation>kopírování selhalo</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Přidáno</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Smazáno</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Odebráno</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Upraveno</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Přejmenováno</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation>Přidáno nebo upraveno</translation>
    </message>
    <message>
        <source>Moved</source>
        <translation>Přemístěno</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Přidán adresář</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Odebraný adresář</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Přejmenovaný adresář</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Přesunutý adresář</translation>
    </message>
    <message>
        <source>files</source>
        <translation>soubory</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>adresáře</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>a %1 dalších</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Stav knihovny navrácen k</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>Stav souboru &quot;%1&quot; byl navrácen k &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Smazaný adresář byl obnoven</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Název nebo popis knihovny byl změněn</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation>Automatické spojení systémem %1</translation>
    </message>
    <message>
        <source>Just now</source>
        <translation>Právě teď</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>Včera</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>před %1 dny</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>před 1 hodinou</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>před %1 hodinami</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>před minutou</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>před %1 minutami</translation>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation>&lt;Not Part of Certificate&gt;</translation>
    </message>
    <message>
        <source>Found another running process of %1, kill it and start a new one?</source>
        <translation>Byl nalezen jiný proces %1, ukončit jej a spustit nový?</translation>
    </message>
    <message>
        <source>Unable to start %1 due to the failure of shutting down the previous process</source>
        <translation>Nepodařilo se spustit %1 kvůli chybě při ukončení předchozího procesu</translation>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation>Synchronizovat tuto knihovnu s:</translation>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation>Synchronizovat tento adresář s:</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Složka</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>Dokument pouze ke čtení</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>PDF Dokument</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>Obrázek</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Video soubor</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Word Dokument</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>PowerPoint Dokument</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Excel Dokument</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation>Cesta &quot;%1&quot; koliduje se systémovou cestou</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation>Cesta &quot;%1&quot; koliduje s existující knihovnou</translation>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>Knihovna &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation>Tato knihovna nebyla stažena</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Chyba:</translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation>každých %1 vteřin</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation>RepoIcon</translation>
    </message>
    <message>
        <source>RepoName</source>
        <translation>RepoName</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Vlastník:</translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>Poslední modifikace:</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation>mtime</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>Místní cesta:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation>RepoStatus</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation>Interval synchronizace:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation>, %1%2</translation>
    </message>
    <message>
        <source>, %1</source>
        <translation>, %1</translation>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation>Tato knihovna nebyla stažena</translation>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation>Nepodařilo se otevřít soubor &quot;%1&quot; v neexistující knihovně &quot;%2&quot;</translation>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation>Nedávno aktualizované</translation>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>Moje knihovny</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>Podknihovny</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation>Sdíleno se mnou</translation>
    </message>
    <message>
        <source>Shared with all</source>
        <translation>Sdíleno se všemi</translation>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation>Sdíleno se skupinama</translation>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation>Synchronizované knihovny</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>spuštění synchronizace</translation>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Zrušit automatickou synchronizaci</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Automatická synchronizace</translation>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation>Zobrazit detaily</translation>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation>Zobrazit detaily knihovny</translation>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation>Synchronizovat tuto knihovnu</translation>
    </message>
    <message>
        <source>Sync this library</source>
        <translation>Synchronizovat tuto knihovnu</translation>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation>Nedávno aktualizované</translation>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation>Synchronizovat</translation>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation>Okamžitě synchronizovat knihovnu</translation>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>Zrušit stahování</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation>Zrušit stahování této knihovny</translation>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>&amp;Otevřít adresář</translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation>otevřít lokální adresář</translation>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation>&amp;Zrušit synchronizaci</translation>
    </message>
    <message>
        <source>unsync this library</source>
        <translation>Zrušit synchronizaci této knihovny</translation>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation>Zobrazit na serveru</translation>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation>Zobrazit tuto knihovnu na serveru</translation>
    </message>
    <message>
        <source>Share to user</source>
        <translation>Sdílet s uživatelem</translation>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation>Sdílet tuto knihovnu s uživatelem</translation>
    </message>
    <message>
        <source>Share to group</source>
        <translation>Sdílet se skupinou</translation>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation>Sdílet tuto knihovnu se skupinou</translation>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation>&amp;Otevřít prohlížeč souborů cloudu</translation>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation>Otevřít tuto knihovnu v Prohlížeči souborů Cloudu</translation>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation>Resynchronizovat knihovnu</translation>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation>Zrušit synchronizaci a znovu synchronizovat tuto knihovnu</translation>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation>Nastavit synchronizaci &amp;Interval</translation>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation>Chyba při rušení synchronizace &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Chyba při rušení ulohy:

%1</translation>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation>Stahování bylo zrušeno</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation>Přepsání souboru %1 sebou samým se nezdařilo</translation>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation>Nelze smazat soubor &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation>Nelze nahrát soubor: %1</translation>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation>Interval synchronizace (ve vteřinách):</translation>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation>Nastavit interval synchronizace pro knihovnu &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>opakovat</translation>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation>Nepodařilo se získat informace o knihovně&lt;br/&gt;Prosím %1</translation>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Varování:&lt;/b&gt; SSL certifikát serveru není důvěryhodný, přesto pokračovat?</translation>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation>přidání základního účtu se nezdařilo</translation>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation>Nezdařilo se spuštění logu: %s</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation>%1 Interní odkaz</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Zkopírovat do schránky</translation>
    </message>
    <message>
        <source>%1 Web Link:</source>
        <translation>%1 webový odkaz:</translation>
    </message>
    <message>
        <source>%1 Protocol Link:</source>
        <translation>%1 protokolový odkaz:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>nepodařilo se načíst konfiguraci ccnet %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Neznámá chyba</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Zrušit automatickou synchronizaci</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Automatická synchronizace</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation>Zobrazit hlavní okno</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation>Otevřít &amp;adresář %1</translation>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation>otevřít %1 adresář</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>Otevřít adresář log souborů</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O aplikaci</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Zobrazit informace O aplikaci</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Online nápověda</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation>automatická synch. je zakázana</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation>Nahrávání</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>otevřít adresář s logy %1</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>otevřít online nápovědu %1</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>některé servery nejsou připojeny</translation>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation>&amp;Zobrazit ve složce</translation>
    </message>
    <message>
        <source>Show in folder</source>
        <translation>Zobrazit ve složce</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>zkusit znovu</translation>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation>Hledání se nezdařilo &lt;br /&gt; Prosím %1</translation>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>Informace o serverech</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>připojeno</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>odpojeno</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation>Nastavte, prosím, heslo knihovny</translation>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation>Zadejte heslo pro knihovnu %1</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Vložte heslo</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>Nesprávné heslo</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Neznámá chyba</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation>Automaticky spustit %1 po přihlášení</translation>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation>Skrýt ikonu %1 ze spouštěče</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Socks5 Proxy</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systémová proxy</translation>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation>Byla provedena změna jazyka. Restartovat pro použití?</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation>Adresa proxy hostitele nesmí být prázdná</translation>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation>Port proxy je nesprávný</translation>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation>Uživatelské jméno proxy nesmí být prázdné</translation>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation>Uživatelské heslo proxy nesmí být prázdné</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation>Skrýt hlavní okno po startu</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Informovat, že knihovny byly synchromizovány</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Povolit synchronizaci pro dočasné soubory MSOffice/Libreoffice</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Download limit (KB/s):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Upload limit (KB/s):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Základní</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation>Nezrušit automaticky synchronizaci knihovny</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation>Nezrušit automaticky synchronizaci knihovny v případě, že je lokální adresář odstraněn nebo je nepřístupný z jiných důvodů</translation>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation>Nezrušit synchronizaci knihovny pokud knihovna není nalezena na serveru</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation>Nezrušit synchronizaci knihovny pokud knihovna není nalezena na serveru</translation>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation>Povolit rozšíření FinderSync</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>Povolit rozšíření Průzkumníku souborů</translation>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>Neověřovat certifikát při HTTPS synchronizaci</translation>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation>Povolit synchronizaci s existujícím adresářem pod jiným názvem</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Rozšířené</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Jazyk (vyžaduje restart)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Typ proxy:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>Proxy server vyžaduje heslo</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Síť</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation>Číst a zapisovat</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation>Pouze číst</translation>
    </message>
    <message>
        <source>Remove Share</source>
        <translation>Zrušit sdílení</translation>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation>Vytvořeno %1</translation>
    </message>
    <message>
        <source>Read Write</source>
        <translation>Číst a zapisovat</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation>Pouze číst</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Skupina</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uživatel</translation>
    </message>
    <message>
        <source>Permission</source>
        <translation>Oprávnění</translation>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation>Předchozí operace stále probíhá</translation>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Sdílet odkaz</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Sdílet odkaz:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>Přímé stažení</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Zkopírovat do schránky</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Login with Shibboleth</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation>Nezabezpečené spojení</translation>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation>%1 používá neplatný zabezpečovací certifikát. Spojení může být nezabezpečené. Opravdu chcete pokračovat?</translation>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation>Aktuální otisk RSA klíče je %1</translation>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation>Předchozí otisk RSA klíče byl %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Zapamatovat výběr</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp; Otevřít</translation>
    </message>
    <message>
        <source>Open this file</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation>zobrazit v prohlížeči</translation>
    </message>
    <message>
        <source>view this file on website</source>
        <translation>otevřít tento soubor v prohlížeči</translation>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation>opakovat</translation>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation>Chyba při stahování informací o oblíbených souborech&lt;br&gt; Prosím %1</translation>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation>Nemáte žádné oblíbené soubory.</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation>Chyba synchronizace souborů</translation>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation>Knihovna</translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Odinstalovat %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Opravdu chcete odebrat informace o účtu %1?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Odebírám informace o účtu...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>text</source>
        <translation>text</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
</context>
</TS>